@@ -18,11 +18,13 @@ package main
 
 import (
 	"github.com/sirupsen/logrus"
+	"github.com/spf13/pflag"
 	veleroplugin "github.com/vmware-tanzu/velero/pkg/plugin/framework"
 )
 
 func main() {
 	veleroplugin.NewServer().
+		BindFlags(pflag.CommandLine).
 		RegisterObjectStore("velero.io/azure", newAzureObjectStore).
 		RegisterVolumeSnapshotter("velero.io/azure", newAzureVolumeSnapshotter).
 		Serve()
